
'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { var callNext = step.bind(null, "next"); var callThrow = step.bind(null, "throw"); function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(callNext, callThrow); } } callNext(); }); }; }

const Bunyan = require('bunyan');

/**
 * Instantiates a logger
 * @class
 */
module.exports = class Logger extends Bunyan {
  /**
   * @constructs
   * @param opts <Object> passed straight through to bunyan.Logger
   */
  constructor(opts) {
    super(Object.assign({
      name: 'koa'
    }, opts || {}));
  }

  /**
   * Attaches the log instance to the koa instance
   * @param opts <Object>
   *   @param as <String> append to context as this string
   * @returns koa middleware function
   */
  attach(opts) {
    opts = Object.assign({
      as: 'logger'
    }, opts || {});

    const logger = this;

    return (function () {
      var ref = _asyncToGenerator(function* (ctx, next) {
        if (ctx[opts.as]) {
          console.warn('ctx.logger already exists');
          yield next();
          return;
        }

        ctx[opts.as] = logger;

        yield next();
      });

      return function (_x, _x2) {
        return ref.apply(this, arguments);
      };
    })();
  }

  /**
   * Basic request log middleware
   * @param opts <Object>
   * @returns koa middleware function
   */
  attachRequest(opts) {
    const logger = this;

    return (function () {
      var ref = _asyncToGenerator(function* (ctx, next) {
        let start = Date.now();

        logger.info({
          event: 'request',
          method: ctx.method,
          url: ctx.url
        });

        yield next();

        logger.info({
          event: 'response',
          method: ctx.method,
          url: ctx.originalUrl,
          status: ctx.status,
          delta: Date.now() - start
        });
      });

      return function (_x3, _x4) {
        return ref.apply(this, arguments);
      };
    })();
  }

};